@@ -15,7 +15,7 @@
 #include "chooselevelsetdialog.h"
 #include "katomic_debug.h"
 
-#include <KStandardGameAction>
+#include <KGameStandardAction>
 
 #include <KLocalizedString>
 #include <KSelectAction>
@@ -72,30 +72,30 @@ bool AtomTopLevel::queryClose()
 void AtomTopLevel::createMenu()
 {
     // Game
-    KStandardGameAction::restart(m_gameWid, &GameWidget::restartLevel, actionCollection());
+    KGameStandardAction::restart(m_gameWid, &GameWidget::restartLevel, actionCollection());
     // FIXME: comment this until highscore dialog will be implemented.
     // (katomic needs special one)
-    //    KStandardGameAction::highscores(m_gameWid, &GameWidget::showHighscores, actionCollection());
-    KStandardGameAction::load(m_gameWid, &GameWidget::loadGame, actionCollection());
-    KStandardGameAction::save(m_gameWid, &GameWidget::saveGame, actionCollection());
-    KStandardGameAction::quit(this, &QWidget::close, actionCollection());
+    //    KGameStandardAction::highscores(m_gameWid, &GameWidget::showHighscores, actionCollection());
+    KGameStandardAction::load(m_gameWid, &GameWidget::loadGame, actionCollection());
+    KGameStandardAction::save(m_gameWid, &GameWidget::saveGame, actionCollection());
+    KGameStandardAction::quit(this, &QWidget::close, actionCollection());
 
     // Move
-    m_undoAct = KStandardGameAction::undo(m_gameWid->playfield(), &PlayField::undo, actionCollection());
-    m_redoAct = KStandardGameAction::redo(m_gameWid->playfield(), &PlayField::redo, actionCollection());
+    m_undoAct = KGameStandardAction::undo(m_gameWid->playfield(), &PlayField::undo, actionCollection());
+    m_redoAct = KGameStandardAction::redo(m_gameWid->playfield(), &PlayField::redo, actionCollection());
 
 
     m_prevLevelAct = actionCollection()->addAction( QStringLiteral(  "prev_level" ) );
     m_prevLevelAct->setIcon( QIcon::fromTheme( QStringLiteral(  "arrow-left" ) ) );
     m_prevLevelAct->setText( i18n( "Previous Level" ) );
-    actionCollection()->setDefaultShortcut(m_prevLevelAct, Qt::CTRL | Qt::Key_P );
+    KActionCollection::setDefaultShortcut(m_prevLevelAct, Qt::CTRL | Qt::Key_P );
     addAction( m_prevLevelAct );
     connect( m_prevLevelAct, &QAction::triggered, m_gameWid, &GameWidget::prevLevel );
 
     m_nextLevelAct = actionCollection()->addAction( QStringLiteral(  "next_level" ) );
     m_nextLevelAct->setIcon( QIcon::fromTheme( QStringLiteral(  "arrow-right" ) ) );
     m_nextLevelAct->setText( i18n( "Next Level" ) );
-    actionCollection()->setDefaultShortcut(m_nextLevelAct, Qt::CTRL | Qt::Key_N );
+    KActionCollection::setDefaultShortcut(m_nextLevelAct, Qt::CTRL | Qt::Key_N );
     addAction( m_nextLevelAct );
     connect( m_nextLevelAct, &QAction::triggered, m_gameWid, &GameWidget::nextLevel );
 
@@ -134,42 +134,37 @@ void AtomTopLevel::createMenu()
 
     QAction * atomUpAct = actionCollection()->addAction( QStringLiteral( "atom_up" ));
     atomUpAct->setText(i18n("Atom Up"));
-    actionCollection()->setDefaultShortcut(atomUpAct, Qt::Key_Up);
+    KActionCollection::setDefaultShortcut(atomUpAct, Qt::Key_Up);
     addAction(atomUpAct);
     connect(atomUpAct, &QAction::triggered, m_gameWid, &GameWidget::moveUp);
 
     QAction * atomDownAct = actionCollection()->addAction( QStringLiteral( "atom_down" ));
     atomDownAct->setText(i18n("Atom Down"));
-    actionCollection()->setDefaultShortcut(atomDownAct,Qt::Key_Down);
+    KActionCollection::setDefaultShortcut(atomDownAct,Qt::Key_Down);
     addAction(atomDownAct);
     connect(atomDownAct, &QAction::triggered, m_gameWid, &GameWidget::moveDown);
 
     QAction * atomLeftAct = actionCollection()->addAction( QStringLiteral( "atom_left" ));
     atomLeftAct->setText(i18n("Atom Left"));
-    actionCollection()->setDefaultShortcut(atomLeftAct,Qt::Key_Left);
+    KActionCollection::setDefaultShortcut(atomLeftAct,Qt::Key_Left);
     addAction(atomLeftAct);
     connect(atomLeftAct, &QAction::triggered, m_gameWid, &GameWidget::moveLeft);
 
     QAction * atomRightAct = actionCollection()->addAction( QStringLiteral( "atom_right" ));
     atomRightAct->setText(i18n("Atom Right"));
-    actionCollection()->setDefaultShortcut(atomRightAct,Qt::Key_Right);
+    KActionCollection::setDefaultShortcut(atomRightAct,Qt::Key_Right);
     addAction(atomRightAct);
     connect(atomRightAct, &QAction::triggered, m_gameWid, &GameWidget::moveRight);
 
     QAction * nextAtomAct = actionCollection()->addAction( QStringLiteral( "next_atom" ));
     nextAtomAct->setText(i18n("Next Atom"));
-    actionCollection()->setDefaultShortcut(nextAtomAct,Qt::Key_Tab);
+    KActionCollection::setDefaultShortcut(nextAtomAct,Qt::Key_Tab);
     addAction(nextAtomAct);
     connect(nextAtomAct, &QAction::triggered, m_gameWid->playfield(), &PlayField::nextAtom);
 
     QAction * prevAtomAct = actionCollection()->addAction( QStringLiteral( "prev_atom" ));
     prevAtomAct->setText(i18n("Previous Atom"));
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    actionCollection()->setDefaultShortcut(prevAtomAct,Qt::SHIFT + Qt::Key_Tab);
-#else
-    const QKeyCombination shortCutPrevious(Qt::SHIFT, Qt::Key_Tab);
-    actionCollection()->setDefaultShortcut(prevAtomAct,shortCutPrevious);
-#endif
+    KActionCollection::setDefaultShortcut(prevAtomAct, Qt::SHIFT | Qt::Key_Tab);
     addAction(prevAtomAct);
     connect(prevAtomAct, &QAction::triggered, m_gameWid->playfield(), &PlayField::previousAtom);
 }
